/**
 * Copyright 2018 Buypass AS, Oslo, Norway
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package no.buypass.api.code.authentication.client;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.jaxrs.json.JacksonJsonProvider;
import org.glassfish.jersey.client.ClientConfig;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.net.ssl.SSLContext;
import javax.net.ssl.TrustManager;
import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.ext.ContextResolver;
import java.security.NoSuchAlgorithmException;

/**
 *
 */
final class JerseyClientFactory {

    private static final Logger LOGGER = LoggerFactory.getLogger(DefaultAuthenticationClient.class);

    private JerseyClientFactory() {
        throw new AssertionError();
    }

    static Client createClient() {
        try {
            SSLContext context = SSLContext.getInstance("TLSv1.2");
            context.init(null, null, new java.security.SecureRandom());
            return ClientBuilder.newBuilder()
                    .withConfig(new ClientConfig())
                    .sslContext(context)
                    .build()
                    .register(JacksonJsonProvider.class)
                    .register(JerseyObjectMapperProvider.class);
        } catch (Exception e) {
            LOGGER.error("Failed to build client with 'TLSv1.2' SSL context", e);
        }
        return ClientBuilder.newClient(new ClientConfig())
                .register(JacksonJsonProvider.class)
                .register(JerseyObjectMapperProvider.class);
    }

    private static class JerseyObjectMapperProvider implements ContextResolver<ObjectMapper> {

        private final ObjectMapper mapper;

        public JerseyObjectMapperProvider() {
            mapper = newMapper();
        }

        @Override
        public ObjectMapper getContext(Class<?> type) {
            return mapper;
        }

        private ObjectMapper newMapper() {
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            return mapper;
        }


        @Override
        public String toString() {
            return getClass().getSimpleName() + " [mapper=" + mapper + "]";
        }

    }

}
