/**
 * Copyright 2018 Buypass AS, Oslo, Norway
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package no.buypass.api.code.authentication.client.exception;

import com.google.common.base.MoreObjects;

/**
 *
 */
public class AuthenticationClientException extends RuntimeException {
    private final int httpStatusCode;

    private final String errorCode;

    public AuthenticationClientException(String message, int httpStatus, String errorCode) {
        super(message);
        this.httpStatusCode = httpStatus;
        this.errorCode = errorCode;
    }

    public AuthenticationClientException(String message, Throwable cause, int httpStatus, String errorCode) {
        super(message, cause);
        this.httpStatusCode = httpStatus;
        this.errorCode = errorCode;
    }

    public int getHttpStatusCode() {
        return httpStatusCode;
    }

    public String getErrorCode() {
        return errorCode;
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("message", getMessage())
                .add("httpStatusCode", httpStatusCode)
                .add("errorCode", errorCode)
                .toString();
    }
}

