/**
 * Copyright 2018 Buypass AS, Oslo, Norway
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package no.buypass.api.code.authentication.client.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.MoreObjects;

import java.util.Objects;

/**
 *
 */
public class UserAuthentication {

    @JsonProperty("authenticated")
    private final boolean authenticated;

    @JsonProperty("sessionId")
    private final String sessionId;

    @JsonProperty("replyMessage")
    private final String replyMessage;

    UserAuthentication(@JsonProperty("authenticated") boolean authenticated,
                       @JsonProperty("sessionId") String sessionId,
                       @JsonProperty("replyMessage") String replyMessage) {
        this.authenticated = authenticated;
        this.sessionId = sessionId;
        this.replyMessage = replyMessage;
    }

    private UserAuthentication(Builder builder) {
        authenticated = builder.authenticated;
        sessionId = builder.sessionId;
        replyMessage = builder.replyMessage;
    }

    public static Builder builder() {
        return new Builder();
    }

    public boolean isAuthenticated() {
        return authenticated;
    }

    public String getSessionId() {
        return sessionId;
    }

    public String getReplyMessage() {
        return replyMessage;
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("authenticated", authenticated)
                .add("sessionId", sessionId)
                .add("replyMessage", replyMessage)
                .toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserAuthentication that = (UserAuthentication) o;
        return authenticated == that.authenticated &&
                Objects.equals(sessionId, that.sessionId) &&
                Objects.equals(replyMessage, that.replyMessage);
    }

    @Override
    public int hashCode() {
        return Objects.hash(authenticated, sessionId, replyMessage);
    }


    public static final class Builder {
        private boolean authenticated;
        private String sessionId;
        private String replyMessage;

        private Builder() {
        }

        public Builder authenticated(boolean val) {
            authenticated = val;
            return this;
        }

        public Builder sessionId(String val) {
            sessionId = val;
            return this;
        }

        public Builder replyMessage(String val) {
            replyMessage = val;
            return this;
        }

        public UserAuthentication build() {
            return new UserAuthentication(this);
        }
    }
}
