/**
 * Copyright 2018 Buypass AS, Oslo, Norway
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package no.buypass.api.code.authentication.client.model;


import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.MoreObjects;

import java.util.Objects;

/**
 *
 */
public class UserCredentials {

    @JsonProperty("userId")
    private final String userId;

    @JsonProperty("appId")
    private final String appId;

    @JsonProperty("secret")
    private final String secret;

    @JsonProperty("sessionId")
    private final String sessionId;

    UserCredentials(@JsonProperty("userId") String userId,
                    @JsonProperty("appId") String appId,
                    @JsonProperty("secret") String secret,
                    @JsonProperty("sessionId") String sessionId) {
        this.userId = userId;
        this.appId = appId;
        this.secret = secret;
        this.sessionId = sessionId;
    }

    private UserCredentials(Builder builder) {
        userId = builder.userId;
        appId = builder.appId;
        secret = builder.secret;
        sessionId = builder.sessionId;
    }

    public static Builder builder() {
        return new Builder();
    }

    public String getUserId() {
        return userId;
    }

    public String getAppId() {
        return appId;
    }

    public String getSecret() {
        return secret;
    }

    public String getSessionId() {
        return sessionId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserCredentials that = (UserCredentials) o;
        return Objects.equals(userId, that.userId) &&
                Objects.equals(appId, that.appId) &&
                Objects.equals(secret, that.secret) &&
                Objects.equals(sessionId, that.sessionId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(userId, appId, secret, sessionId);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("userId", userId)
                .add("appId", appId)
                .add("secret", "********")
                .add("sessionId", sessionId)
                .toString();
    }


    public static final class Builder {
        private String userId;
        private String appId;
        private String secret;
        private String sessionId;

        private Builder() {
        }

        public Builder userId(String val) {
            userId = val;
            return this;
        }

        public Builder appId(String val) {
            appId = val;
            return this;
        }

        public Builder secret(String val) {
            secret = val;
            return this;
        }

        public Builder sessionId(String val) {
            sessionId = val;
            return this;
        }

        public UserCredentials build() {
            return new UserCredentials(this);
        }
    }
}
